@@ -1,8 +1,9 @@
+import logging
 from pathlib import Path
 
 from m23.constants import FLUX_LOGS_COMBINED_FOLDER_NAME
 from m23.processor.process_nights import normalization_helper
-from m23.utils import get_date_from_input_night_folder_name
+from m23.utils import get_date_from_input_night_folder_name, get_log_file_name
 
 from .renormalize_config_loader import (
     RenormalizeConfig,
@@ -13,12 +14,26 @@ from .renormalize_config_loader import (
 def renormalize_auxiliary(renormalize_dict: RenormalizeConfig):
     for night in renormalize_dict["input"]["nights"]:
         NIGHT_FOLDER = night["path"]
+        night_date = (get_date_from_input_night_folder_name(NIGHT_FOLDER.name),)
+        log_file_path = NIGHT_FOLDER / get_log_file_name(night_date)
+        radii_of_extraction = (renormalize_dict["processing"]["radii_of_extraction"],)
+        logging.basicConfig(
+            filename=log_file_path,
+            format="%(asctime)s %(message)s",
+            level=logging.INFO,
+        )
+        logging.info(f"Running renormalization for radii {radii_of_extraction}")
+
+        LOG_FILES_COMBINED_FOLDER: Path = NIGHT_FOLDER / FLUX_LOGS_COMBINED_FOLDER_NAME
+        # Create log files combined folder if it doesn't yet exist
+        LOG_FILES_COMBINED_FOLDER.mkdir(exist_ok=True)
+
         normalization_helper(
-            renormalize_dict["processing"]["radii_of_extraction"],
-            NIGHT_FOLDER / FLUX_LOGS_COMBINED_FOLDER_NAME,
+            radii_of_extraction,
+            LOG_FILES_COMBINED_FOLDER,
             renormalize_dict["reference"]["file"],
             night["files_to_use"],
-            get_date_from_input_night_folder_name(NIGHT_FOLDER.name),
+            night_date,
         )
 
 
